@@ -59,6 +59,24 @@ def filter_clusters(
     return clusters_data
 
 
+def filter_deployments(
+    deployments_data: List[Dict],
+    clusters_data=None,
+    machines_data=None,
+    pods_data=None,
+    cgroups_data=None,
+    containers_data=None,
+    **filters,
+):
+    filter_set = {
+        cfgs.NAMESPACE_FIELD: lambda data, filt: filter_obj(
+            data, [[lib.METADATA_FIELD, lib.NAMESPACE_FIELD]], filt
+        ),
+    }
+    deployments_data = use_filters(deployments_data, filter_set, filters)
+    return deployments_data
+
+
 def filter_namespaces(
     namespaces_data: List[Dict],
     clusters_data=None,
@@ -201,6 +219,8 @@ def filter_fingerprints(
     cgroups_data=None,
     containers_data=None,
     use_context_filters=True,
+    suppress_warning=False,
+    not_matching=False,
     **filters,
 ):
     def cont_id_filter(data, filt):
@@ -253,9 +273,26 @@ def filter_fingerprints(
         lib.NAMESPACE_LABELS_FIELD: filter_namespace_labels,
         lib.POD_LABELS_FIELD: filter_pod_labels,
     }
-    fingerprint_data = use_filters(
-        fingerprint_data, filter_set, filters, use_context_filters
-    )
+    if not_matching:
+        non_matches = []
+        for fingerprint in fingerprint_data:
+            if not use_filters(
+                [fingerprint],
+                filter_set,
+                filters,
+                use_context_filters,
+                suppress_warning=True,
+            ):
+                non_matches.append(fingerprint)
+        fingerprint_data = non_matches
+    else:
+        fingerprint_data = use_filters(
+            fingerprint_data,
+            filter_set,
+            filters,
+            use_context_filters,
+            suppress_warning=suppress_warning,
+        )
     return fingerprint_data
 
 
@@ -330,7 +367,11 @@ def filter_connections(
 
 
 def use_filters(
-    data, filter_functions: Dict, filters: Dict, use_context_filters=True
+    data,
+    filter_functions: Dict,
+    filters: Dict,
+    use_context_filters=True,
+    suppress_warning=False,
 ):
     ctx_filters = cfgs.get_current_context().get_filters()
     data_empty_at_start = len(data) == 0
@@ -339,8 +380,8 @@ def use_filters(
             data = func(data, filters[filt])
         elif use_context_filters and filt in ctx_filters:
             data = func(data, ctx_filters[filt])
-        if len(data) == 0 and not data_empty_at_start:
-            lib.try_log(f"No results after filtering on {filt}")
+        if len(data) == 0 and not data_empty_at_start and not suppress_warning:
+            lib.try_log(f"No results after filtering on '{filt}'")
             return data
     return data
 
